from .my_math import MathOperations

def test_add():
    calculator = MathOperations(2,3)
    assert calculator.add() == 5

def test_sub():
    calculator = MathOperations(3,2)
    assert calculator.sub() == 1

def test_mult():
    calculator = MathOperations(2,2)
    assert calculator.mult() == 4

def test_div():
    calculator = MathOperations(2,2)
    assert calculator.div() == 1


class MathOperations():
    def __init__(self, num1, num2):
        self.num1 = num1
        self.num2 = num2
    def add(self):
        return self.num1 + self.num2
    def sub(self):
        return self.num1 - self.num2
    def mult(self):
        return self.num1 * self.num2
    def div(self):
        if self.num2 == 0:
            raise Exception('Sorry, I cannot divide by 0!')
        else:
            return self.num1 / self.num2